How to Build Documentation
==========================

To make the html documentation, first install the Diofant
:ref:`from sources <installation-src>` with ``docs`` extra
requirement, then enter the project directory and run::

    python setup.py build_sphinx

Documentation tree will be located in the build/sphinx/html/ directory.
